@@ -4,7 +4,7 @@
  * Project: GGZCards Server/Client
  * Date: 06/26/2001
  * Desc: Enumerations for the ggzcards client-server protocol
- * $Id: protocol.h 6293 2004-11-07 05:51:47Z jdorje $
+ * $Id: protocol.h 8561 2006-08-31 08:00:24Z jdorje $
  *
  * This just contains the communications protocol information.
  *
@@ -39,6 +39,15 @@
 
 #include "cards.h"
 
+typedef struct {
+	int score;
+
+#define SCORE_EXTRAS 1
+	/* Extra fields for supplemental score data. */
+	int extra[SCORE_EXTRAS];
+} score_data_t;
+
+#define NO_BID_VAL -1
 
 /* 
  * Protocol opcodes
@@ -62,8 +71,9 @@ typedef enum {
 	   data. */
 	REQ_NEWGAME,
 
-	/* Tells the client of a start of a new game.  Followed by an
-	   integer containing the cardset type. */
+	/* Tells the client of a start of a new game.  Followed by a
+	   string containing the game type, and an integer containing the
+	   cardset type. */
 	MSG_NEWGAME,
 
 	/* Tells the client of a gameover situation.  It'll be followed by an 
@@ -71,13 +81,27 @@ typedef enum {
 	   the game. */
 	MSG_GAMEOVER,
 
-	/* Tells the client the list of players.  It'll be followd by an
-	   integer n followed by data for all n players.  For each player, an 
-	   integer giving the seat status (GGZSeat) and a string for the
-	   player's name will be sent.  Note that the names may be invalid
-	   (but never null) for OPEN seats. */
+	/* Tells the client the list of seats.  It'll be followed by an
+	   integer containing the number of seats, one containing the number
+	   of players, and one containing the
+	   number of teams, followed by data for all seats.  For each
+	   seat, an integer giving the seat status (GGZSeat), a string for the
+	   seats's name, and integer for the player sitting at the seat, and
+	   and integer for the team of that player will be sent.  Note that
+	   the names may be invalid or empty for OPEN seats. */
 	MSG_PLAYERS,
 
+	/* Tells the client scores.  Consists of the hand number (between 0
+	   and the current hand), an integer containing the number of "extra"
+	   scores (0 or higher), and one score per team.  Each score consists
+	   of an integer for the main score plus one integer for each extra
+	   score. */
+	MSG_SCORES,
+
+	/* Tells the client tricks.  Consists of one integer per player that gives
+	   the number of tricks won by that player (only applicable in some games). */
+	MSG_TRICKS_COUNT,
+
 	/* Requests options from the client.  It is followed by an integer n
 	   followed by n option requests.  Each option request consists of a
 	   descriptive text for the option, an integer m telling how many
@@ -90,14 +114,36 @@ typedef enum {
 	   RSP_OPTIONS in response. */
 	REQ_OPTIONS,
 
-	/* Tells the client a new hand is starting.  No data. */
+	/* Tells the client a new hand is starting.  It is followed by an
+	   single integer containing the hand number (hand counting
+	   starts at 0), then by the 'dealer' seat. */
 	MSG_NEWHAND,
 
+	/* Contains a single byte that tells the trump suit. */
+	MSG_TRUMP,
+
 	/* Tells the client of a player's hand.  It'll be followed by a seat
 	   # for whom the hand belongs to, followed by an integer n for the
 	   hand size, followed by n cards. */
 	MSG_HAND,
 
+	/* Tells the client the status of each player.  This consists of two
+	   integers, each of which is a bit vector containing one bit per
+	   player.  The first integer has bits set if the player is bidding,
+	   the second if the player is playing. */
+	MSG_PLAYERS_STATUS,
+
+	/* Requests a bid from the client.  It'll be followed by an integer
+	   n, then n bid choices.  Each bid choice consists of the bid
+	   itself (see read_bid/write_bid) and two strings: a short bid
+	   text, and a longer bid description.  The client must choose one 
+	   of these bids and send a RSP_BID in response. */
+	REQ_BID,
+
+	/* Tells the client of a player's bid.  It is followed by a seat # for
+	   the seat from which the bid comes, then the bid itself. */
+	MSG_BID,
+
 	/* Requests a play (of a card) from the client.  It'll be followd by
 	   the seat # of the hand from which the client is supposed to play
 	   (only a few games, like bridge, ever require a player to play from 
@@ -119,56 +165,32 @@ typedef enum {
 	   # giving the player who won the trick. */
 	MSG_TRICK,
 
-	/* Requests a bid from the client.  It'll be followed by an integer
-	   n, then n bid choices.  Each bid choice consists of the bid
-	   itself (see read_bid/write_bid) and two strings: a short bid
-	   text, and a longer bid description.  The client must choose one 
-	   of these bids and send a RSP_BID in response. */
-	REQ_BID,
-
-	/* Tells the client of a player's bid.  It is followed by a seat # for
-	   the seat from which the bid comes, then the bid itself. */
-	MSG_BID,
-
 	/* Sends out the current table to the client.  It is followed by a
 	   card for each player, in order.  Note that only one card per
 	   player/seat may be on the table at a time. */
 	MSG_TABLE,
 
-	/* A game message.  See game_message_t below. */
-	MESSAGE_GAME,
+	/* A simple text message, containing two strings: a "marker" and the
+	   "message". */
+	MSG_GAME_MESSAGE_TEXT,
+
+	/* A text message for the player, consisting of a seat # followed by
+	   a message string. */
+	MSG_GAME_MESSAGE_PLAYER,
+
+	/* A list of cards for each player.  First comes a "marker" string,
+	   then (for each player) an integer n plus n cards for that player. */
+	MSG_GAME_MESSAGE_CARDLIST,
+
+	/* Block data that may be game-specific.  It is up to the client
+	   frontend to determine what (if anything) to do  with this data;
+	   it'll be built at the server end by the game module. */
+	MSG_GAME_SPECIFIC,
 } server_msg_t;
 
 /** @brief Return a string description of the opcode. */
 const char *get_server_opcode_name(server_msg_t opcode);
 
-/* Global message types */
-/* Each MESSAGE_GAME will be followed by one of these opcodes.  This
-   represents game-specific data being transmitted to the frontend. */
-typedef enum {
-	/* A simple text message, containing two strings: a "marker" and the
-	   "message". */
-	GAME_MESSAGE_TEXT,
-
-	/* A text message for the player, consisting of a seat # followed by
-	   a message string. */
-	GAME_MESSAGE_PLAYER,
-
-	/* A list of cards for each player.  First comes a "marker" string,
-	   then (for each player) an integer n plus n cards for that player. */
-	GAME_MESSAGE_CARDLIST,
-
-	/* Block data that may be game-specific.  It is followed by the
-	   (string) name of the game, followed by an integer n followed
-	   by n bytes of data. It is up to the client frontend to determine
-	   what (if anything) to do  with this data; it'll be build at the
-	   server end by the game module. */
-	GAME_MESSAGE_GAME,
-} game_message_t;
-
-/** @brief Return a string description of the opcode. */
-const char *get_game_message_name(game_message_t opcode);
-
 /* Messages from client */
 typedef enum {
 	/* Notifies the server of the client's language.  Followed by a
